@@ -23,7 +23,7 @@
 #include <xmmintrin.h>
 #include "alignment.h"
 
-#include "pick_anchor.h"
+
 #define MAX(a, b) (a > b ? a : b)
 #define MAX3(a,b,c) MAX(MAX(a,b),c)
 
@@ -136,7 +136,7 @@ int** hirschberg_alignment(struct msa* msa, struct aln_param* ap)
                 b = tree[i*3+1];
                 c = tree[i*3+2];
                 //fprintf(stderr,"\r%8.0f percent done",(float)(i) /(float)numseq * 100);
-                //fprintf(stderr,"Aligning:%d %d->%d	done:%f\n",a,b,c,((float)(i+1)/(float)numseq)*100);
+                //fprintf(stdout,"Aligning:%d %d->%d	done:%f\n",a,b,c,((float)(i+1)/(float)numseq)*100);
                 if(a < numseq){
                         len_a = msa->sequences[a]->len;//  aln->sl[a];
                 }else{
@@ -280,6 +280,7 @@ int hirsch_ss_dyn(const struct aln_param* ap, const uint8_t* seq1,const uint8_t*
 
 
         hirsch_align_two_ss_vector(ap,seq1,seq2,hm,hirsch_path,input_states,old_cor);
+
         return  OK;
 }
 
@@ -546,7 +547,7 @@ int hirsch_align_two_ss_vector(const struct aln_param* ap,const uint8_t* seq1,co
 
 
         //fprintf(stderr,"Transition:%d	at:%d\n",transition,c);
-
+        //LOG_MSG("MAX: %f",max);
         //j = hirsch_path[0];
         switch(transition){
         case 1: //a -> a = 1
@@ -1965,7 +1966,7 @@ int hirsch_align_two_pp_vector(const float* prof1,const float* prof2,struct hirs
 
 int foward_hirsch_pp_dyn(const float* prof1,const float* prof2,struct hirsch_mem* hm)
 {
-        unsigned int freq[21];
+        unsigned int freq[23];
 
         struct states* s = hm->f;
         register float pa = 0;
@@ -2015,7 +2016,7 @@ int foward_hirsch_pp_dyn(const float* prof1,const float* prof2,struct hirsch_mem
                 prof1 += 64;
                 //c = 1;
                 f = 0;
-                for (j = 0;j < 21; j++){
+                for (j = 0;j < 23; j++){
                         if(prof1[j]){
                                 freq[f] = j;
                                 f++;
@@ -2100,7 +2101,7 @@ int foward_hirsch_pp_dyn(const float* prof1,const float* prof2,struct hirsch_mem
 
 int backward_hirsch_pp_dyn(const float* prof1,const float* prof2,struct hirsch_mem* hm)
 {
-        unsigned int freq[21];
+        unsigned int freq[23];
         struct states* s = hm->b;
         register float pa = 0;
         register float pga = 0;
@@ -2148,7 +2149,7 @@ int backward_hirsch_pp_dyn(const float* prof1,const float* prof2,struct hirsch_m
 
                 //c = 1;
                 f = 0;
-                for (j = 0;j < 21; j++){
+                for (j = 0;j < 23; j++){
                         if(prof1[j]){
                                 freq[f] = j;
                                 f++;
@@ -2380,10 +2381,8 @@ float* make_profile(struct aln_param* ap,const uint8_t* seq,const int len)
         int i,j,c;
         float** subm = NULL;
         float* prof = NULL;
-
         float gpo,gpe,tgpe;
 
-
         gpo = ap->gpo;
         gpe = ap->gpe;
         tgpe = ap->tgpe;
@@ -2399,7 +2398,6 @@ float* make_profile(struct aln_param* ap,const uint8_t* seq,const int len)
         prof[24+32] = -gpe;
         prof[25+32] = -tgpe;
 
-
         i = len;
         while(i--){
                 prof -= 64;
@@ -2748,7 +2746,6 @@ ERROR:
 
 int hirsch_mem_realloc(struct hirsch_mem* hm,int x)
 {
-
         if((x+1) > hm->size){
                 hm->size = x+1;
 
