@@ -34,12 +34,21 @@ struct parameters{
         char *outfile;
         char* format;
         char* aln_param_file;
+        float gpo;
+        float gpe;
+        float tgpe;
+        float matadd;
+        int chaos;
         int out_format;
         int param_set;
         int dist_method;
         int num_infiles;
         int reformat;
         int rename;             /* rename sequences - to make bali_score swallow the alignments */
+        int dump_internal;
+        int nthreads;
+        int clean;
+        int unalign;
         int help_flag;
 };
 
